corefuncs

package
v1.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 14, 2023 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetFunc added in v1.5.0

func GetFunc(i interface{}) *runtime.Func

func GetFuncFullName added in v1.5.0

func GetFuncFullName(i interface{}) string

GetFuncFullName

Get the function name, passing non function may result panic

func GetFuncName added in v1.5.0

func GetFuncName(i interface{}) string

Types

type ActionFunc

type ActionFunc func()

type ActionReturnsErrorFunc

type ActionReturnsErrorFunc func() error

type ActionReturnsErrorFuncWrapper

type ActionReturnsErrorFuncWrapper struct {
	Name   string
	Action ActionReturnsErrorFunc
}

func (ActionReturnsErrorFuncWrapper) AsActionFunc

func (it ActionReturnsErrorFuncWrapper) AsActionFunc() ActionFunc

func (ActionReturnsErrorFuncWrapper) AsActionReturnsErrorFunc

func (it ActionReturnsErrorFuncWrapper) AsActionReturnsErrorFunc() ActionReturnsErrorFunc

func (ActionReturnsErrorFuncWrapper) Exec

type BaseJsonResultProcessorFunc

type BaseJsonResultProcessorFunc func(baseJsonResulter serializerinf.BaseJsonResulter) (basicError errcoreinf.BasicErrWrapper)

type BytesCollectionPayloadsProcessorFunc

type BytesCollectionPayloadsProcessorFunc func(collectionOfBytes *corejson.BytesCollection) (err error)

type ErrorToBasicError

type ErrorToBasicError func(
	errorTyper errcoreinf.BaseErrorTyper,
	err error,
) (basicError errcoreinf.BasicErrWrapper)

type ExecFunc

type ExecFunc func()

type InActionReturnsErrFunc

type InActionReturnsErrFunc func(input interface{}) (err error)

type InOutErrFunc

type InOutErrFunc func(input interface{}) (output interface{}, err error)

type InOutErrFuncWrapper

type InOutErrFuncWrapper struct {
	Name   string
	Action InOutErrFunc
}

func (InOutErrFuncWrapper) AsActionFunc

func (it InOutErrFuncWrapper) AsActionFunc(input interface{}) ActionFunc

func (InOutErrFuncWrapper) AsActionReturnsErrorFunc

func (it InOutErrFuncWrapper) AsActionReturnsErrorFunc(
	input interface{},
) ActionReturnsErrorFunc

func (InOutErrFuncWrapper) Exec

func (it InOutErrFuncWrapper) Exec(
	input interface{},
) (output interface{}, err error)

type InOutFunc

type InOutFunc func(input interface{}) (output interface{})

type IsApplyFunc

type IsApplyFunc func() (isSuccess bool)

type IsBooleanFunc added in v1.5.0

type IsBooleanFunc func() bool

type IsFailureFunc

type IsFailureFunc func() (isFailed bool)

type IsSuccessFunc

type IsSuccessFunc func() (isSuccess bool)

type IsSuccessFuncWrapper

type IsSuccessFuncWrapper struct {
	Name   string
	Action IsSuccessFunc
}

func (IsSuccessFuncWrapper) AsActionFunc

func (it IsSuccessFuncWrapper) AsActionFunc() ActionFunc

func (IsSuccessFuncWrapper) AsActionReturnsErrorFunc

func (it IsSuccessFuncWrapper) AsActionReturnsErrorFunc() ActionReturnsErrorFunc

func (IsSuccessFuncWrapper) Exec

func (it IsSuccessFuncWrapper) Exec() (isSuccess bool)

type JsonResultProcessorFunc

type JsonResultProcessorFunc func(result *corejson.Result) (basicError errcoreinf.BasicErrWrapper)

type JsonResulterProcessorFunc

type JsonResulterProcessorFunc func(result serializerinf.JsonResulter) (basicError errcoreinf.BasicErrWrapper)

type MultiPayloadsProcessorFunc

type MultiPayloadsProcessorFunc func(multiPayloads ...[]byte) (err error)

type NamedActionFunc

type NamedActionFunc func(name string)

type NamedActionFuncWrapper

type NamedActionFuncWrapper struct {
	Name   string
	Action NamedActionFunc
}

func (NamedActionFuncWrapper) AsActionFunc

func (it NamedActionFuncWrapper) AsActionFunc() ActionFunc

func (NamedActionFuncWrapper) AsActionReturnsErrorFunc

func (it NamedActionFuncWrapper) AsActionReturnsErrorFunc() ActionReturnsErrorFunc

func (NamedActionFuncWrapper) Exec

func (it NamedActionFuncWrapper) Exec()

func (NamedActionFuncWrapper) Next

type NextPayloadProcessorLinkerFunc

type NextPayloadProcessorLinkerFunc func(nextLinkerFunc PayloadProcessorFunc) error

type NextReturnErrWrapperFunc

type NextReturnErrWrapperFunc func(nextAction ActionReturnsErrorFunc) error

type NextVoidActionFunc

type NextVoidActionFunc func(nextAction ExecFunc)

type PayloadProcessorFunc

type PayloadProcessorFunc func(payloads []byte) (err error)

type PayloadToBasicErrProcessorFunc

type PayloadToBasicErrProcessorFunc func(payloads []byte) (basicError errcoreinf.BasicErrWrapper)

type PayloadToPayloadWrapperFunc

type PayloadToPayloadWrapperFunc func(payloads []byte) (payloadWrapper *corepayload.PayloadWrapper, err error)

type PayloadWrapperProcessorFunc

type PayloadWrapperProcessorFunc func(payloadWrapper *corepayload.PayloadWrapper) (basicError errcoreinf.BasicErrWrapper)

type ResultDelegatingFunc

type ResultDelegatingFunc func(resultDelegatedTo interface{}) error

ResultDelegatingFunc

resultDelegatedTo can be unmarshal or marshal or reflect set

type ResultDelegatingFuncWrapper

type ResultDelegatingFuncWrapper struct {
	Name   string
	Action ResultDelegatingFunc
}

func (ResultDelegatingFuncWrapper) AsActionFunc

func (it ResultDelegatingFuncWrapper) AsActionFunc(toPointer interface{}) ActionFunc

func (ResultDelegatingFuncWrapper) AsActionReturnsErrorFunc

func (it ResultDelegatingFuncWrapper) AsActionReturnsErrorFunc(
	toPointer interface{},
) ActionReturnsErrorFunc

func (ResultDelegatingFuncWrapper) Exec

func (it ResultDelegatingFuncWrapper) Exec(
	toPointer interface{},
) error

type SerializeOutputFunc

type SerializeOutputFunc func(input interface{}) (serializedBytes []byte, err error)

type SerializerVoidFunc

type SerializerVoidFunc func() (serializedBytes []byte, err error)

type SimpleBytesResultProcessorFunc

type SimpleBytesResultProcessorFunc func(simpleBytes serializerinf.SimpleBytesResulter) (basicError errcoreinf.BasicErrWrapper)

type StringerActionFunc

type StringerActionFunc func() (result string)

type StringerWithErrorActionFunc

type StringerWithErrorActionFunc func() (result string, err error)

Jump to